Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1456)

Unified Diff: chrome/browser/policy/proto/device_management_local.proto

Issue 6532019: New policy protobuf protocol. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix one more leak Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/proto/device_management_local.proto
diff --git a/chrome/browser/policy/proto/device_management_local.proto b/chrome/browser/policy/proto/device_management_local.proto
index a991551dfc0e26e79c6920572ee045c2fe0656f1..45c299400f7c2d1b43527324564a73e532438ff0 100644
--- a/chrome/browser/policy/proto/device_management_local.proto
+++ b/chrome/browser/policy/proto/device_management_local.proto
@@ -10,14 +10,18 @@ package enterprise_management;
import "device_management_backend.proto";
-// Wrapper around DevicePolicyResponse for caching on disk.
-message CachedDevicePolicyResponse {
+// Wrapper around CloudPolicyResponse/DevicePolicyResponse for caching on disk.
+message CachedCloudPolicyResponse {
// The DevicePolicyResponse wrapped by this message.
- optional DevicePolicyResponse policy = 1;
- // Timestamp noting when this policy was cached.
+ optional DevicePolicyResponse device_policy = 1;
+ // Timestamp noting when the |unmanaged| flag was set. The data format is
+ // a unix timestamp. When caching (deprecated) DevicePolicyResponses, this
+ // timestamp also notes when the response was cached.
optional uint64 timestamp = 2;
// Flag that is set to true if this device is not managed.
optional bool unmanaged = 3;
+ // The CloudPolicyResponse wrapped by this message.
+ optional CloudPolicyResponse cloud_policy = 4;
}
// Encapsulates a device ID and the associated device token.

Powered by Google App Engine
This is Rietveld 408576698